@@ -26,7 +26,7 @@
 
 __authors__ = ["J. Garriga"]
 __license__ = "MIT"
-__date__ = "14/04/2020"
+__date__ = "08/12/2020"
 
 import numpy
 import silx.math
@@ -37,8 +37,8 @@ class Method(_Enum):
     """
     Methods available to compute the background.
     """
-    mean = "mean"
     median = "median"
+    mean = "mean"
 
 
 def background_subtraction(data, bg_frames, method='median'):
@@ -65,7 +65,7 @@ def background_subtraction(data, bg_frames, method='median'):
             raise ValueError("Invalid method specified. Please use `mean`, "
                              "or `median`.")
     if data.dtype.kind == 'i' or data.dtype.kind == 'u':
-        new_data = numpy.subtract(data, background, dtype=numpy.int64)
+        new_data = numpy.subtract(data, background, dtype=numpy.int32)
     else:
         new_data = numpy.subtract(data, background)
     new_data[new_data < 0] = 0
@@ -102,7 +102,7 @@ def background_subtraction_2D(img, bg):
     :return: Image with subtracted background
     """
     if img.dtype.kind == 'i' or img.dtype.kind == 'u':
-        img = numpy.subtract(img, bg.astype(img.dtype), dtype=numpy.int64)
+        img = numpy.subtract(img, bg.astype(img.dtype), dtype=numpy.int32)
     else:
         img = numpy.subtract(img, bg.astype(img.dtype))
     img[img < 0] = 0
@@ -163,7 +163,7 @@ def _create_n_sphere_mask(shape, center=None, radius=None):
     return mask
 
 
-def chunk_image(img, start, chunk_shape):
+def chunk_image(start, chunk_shape, img):
     """
     Return a chunk of an image.
 
@@ -196,18 +196,17 @@ def hot_pixel_removal_2D(image, ksize=3):
     :param int ksize: Size of the mask to apply.
     :returns: ndarray
     """
-    corrected_image = numpy.empty(image.shape, dtype=image.dtype)
     if image.dtype == numpy.int or image.dtype == numpy.uint:
         # Cast to int and not uint to later subtract
         image = image.astype(numpy.int16)
     elif image.dtype == numpy.float:
         image = image.astype(numpy.float32)
     corrected_image = numpy.array(image)
-    median = silx.math.medfilt(image, ksize)
+    median = silx.math.medfilt(corrected_image, ksize)
     if image.dtype.kind == 'i' or image.dtype.kind == 'u':
-        hot_pixels = numpy.subtract(image, median, dtype=numpy.int64)
+        hot_pixels = numpy.subtract(corrected_image, median, dtype=numpy.int32)
     else:
-        hot_pixels = numpy.subtract(image, median)
+        hot_pixels = numpy.subtract(corrected_image, median)
     threshold = numpy.std(hot_pixels)
     corrected_image[hot_pixels > threshold] = median[hot_pixels > threshold]
     return corrected_image
@@ -223,15 +222,10 @@ def threshold_removal(data, bottom=None, top=None):
     :returns: ndarray
     """
 
-    frames = []
+    new_data = numpy.array(data, dtype=data.dtype)
+    if bottom is not None:
+        new_data[new_data < bottom] = 0
+    if top is not None:
+        new_data[new_data > top] = 0
 
-    for frame in data:
-        median = numpy.median(frame)
-        if bottom is not None:
-            frame[frame < bottom] = median
-        if top is not None:
-            frame[frame > top] = median
-
-        frames.append(frame)
-
-    return numpy.asarray(frames)
+    return new_data
