@@ -35,9 +35,17 @@ import fabio
 import numpy
 import string
 
+from silx.resources import ExternalResources
+
 from darfix.core.dataset import Dataset
 
 
+utilstest = ExternalResources(project="darfix",
+                              url_base="http://www.edna-site.org/pub/darfix/testimages",
+                              env_key="DATA_KEY",
+                              timeout=60)
+
+
 def random_generator(size=4, chars=string.printable):
     """
     Returns a string with random characters.
@@ -45,13 +53,13 @@ def random_generator(size=4, chars=string.printable):
     return ''.join(chars[numpy.random.choice(len(chars))] for x in range(size))
 
 
-def createRandomDataset(dims, nb_data_files=10, nb_dark_files=2, header=False, _dir=None):
+def createRandomDataset(dims, nb_data_files=20, header=False, _dir=None, in_memory=True):
     """Simple creation of a dataset in _dir with the requested number of data
     files and dark files.
 
     :param tuple of int dims: dimensions of the files.
     :param int nb_data_files: Number of data files to create.
-    :param int nb_data_files: Number of dark files to create.
+    :param int nb_dark_files: Number of dark files to create.
     :param bool header: If True, a random header is created for every frame.
     :param str or None _dir: Directory to save the temporary files.
 
@@ -59,12 +67,8 @@ def createRandomDataset(dims, nb_data_files=10, nb_dark_files=2, header=False, _
     """
     assert type(dims) is tuple and len(dims) == 2
     assert type(nb_data_files) is int
-    assert type(nb_dark_files) is int
     # assert type(nb_ff_file) is int
     assert type(_dir) in (type(None), str)
-    assert nb_dark_files > 0
-
-    dark_filename = None
 
     if _dir is None:
         _dir = tempfile.mkdtemp()
@@ -74,12 +78,13 @@ def createRandomDataset(dims, nb_data_files=10, nb_dark_files=2, header=False, _
 
     if header:
         counter_mne = "a b c d e f g h"
-        motor_mne = "x y z k h m n"
+        motor_mne = "obpitch y z mainx ffz m obx"
         # Create headers
         header = []
         # Dimensions for reshaping
         a = numpy.random.rand(2)
         b = numpy.random.rand(5)
+        c = numpy.random.rand(2)
         motors = numpy.random.rand(7)
         for i in numpy.arange(nb_data_files):
             header.append({})
@@ -88,13 +93,15 @@ def createRandomDataset(dims, nb_data_files=10, nb_dark_files=2, header=False, _
             header[i]["motor_mne"] = motor_mne
             header[i]["counter_pos"] = ""
             header[i]["motor_pos"] = ""
-            for c in counter_mne:
+            for count in counter_mne:
                 header[i]["counter_pos"] += str(numpy.random.rand(1)[0]) + " "
             for j, m in enumerate(motor_mne.split()):
                 if m == "z":
-                    header[i]["motor_pos"] += str(a[i % 2]) + " "
+                    header[i]["motor_pos"] += str(a[int((i > 4 and i < 10) or i > 14)]) + " "
                 elif m == "m":
                     header[i]["motor_pos"] += str(b[i % 5]) + " "
+                elif m == "obpitch":
+                    header[i]["motor_pos"] += str(c[int(i > 9)]) + " "
                 else:
                     header[i]["motor_pos"] += str(motors[j]) + " "
 
@@ -106,19 +113,12 @@ def createRandomDataset(dims, nb_data_files=10, nb_dark_files=2, header=False, _
             data_file = os.path.join(_dir, 'data_file%04i.edf' % index)
             image = fabio.edfimage.EdfImage(data=numpy.random.random(dims))
             image.write(data_file)
-    raw_filename = _dir + '/data_file%04i.edf' % 0
-    for index in range(nb_dark_files):
-        dark_file = os.path.join(_dir, 'dark_file%04i.edf' % index)
-        image = fabio.edfimage.EdfImage(data=numpy.random.random(dims))
-        image.write(dark_file)
-    if nb_dark_files > 0:
-        dark_filename = os.path.join(_dir, 'dark_file%04i.edf' % 0)
 
-    dataset = Dataset(raw_filename=raw_filename, dark_filename=dark_filename)
+    dataset = Dataset(_dir=_dir, in_memory=in_memory)
     return dataset
 
 
-def createDataset(data, dark_frames=None, filter_data=False, header=None, _dir=None):
+def createDataset(data, filter_data=False, header=None, _dir=None, in_memory=True):
     """
     Create a dataset from a configuration
 
@@ -150,17 +150,7 @@ def createDataset(data, dark_frames=None, filter_data=False, header=None, _dir=N
             image = fabio.edfimage.EdfImage(data=data[index])
 
         image.write(data_file)
-    raw_filename = os.path.join(_dir, 'data_file%04i.edf' % 0)
 
-    dark_filename = None
-    if dark_frames is not None:
-        for index in range(len(dark_frames)):
-            data_file = os.path.join(_dir, 'dark_file%04i.edf' % index)
-            image = fabio.edfimage.EdfImage(data=dark_frames[index])
-            image.write(data_file)
-        dark_filename = os.path.join(_dir, 'dark_file%04i.edf' % 0)
-
-    dataset = Dataset(raw_filename=raw_filename, dark_filename=dark_filename,
-                      filter_data=filter_data)
+    dataset = Dataset(_dir=_dir, in_memory=in_memory)
 
     return dataset
