@@ -34,6 +34,7 @@ from silx.gui import qt
 from Orange.widgets.widget import OWWidget, Input, Output
 from darfix.gui.magnificationWidget import MagnificationWidget
 from darfix.gui.rsmWidget import RSMWidget
+from darfix.core.process import Transformation
 
 
 class TransformationWidgetOW(OWWidget):
@@ -42,8 +43,9 @@ class TransformationWidgetOW(OWWidget):
     """
 
     name = "transformation"
-    # icon = "icons/pca.png"
+    icon = "icons/axes.png"
     want_main_area = False
+    ewokstaskclass = Transformation
 
     # Inputs
     class Inputs:
@@ -70,20 +72,21 @@ class TransformationWidgetOW(OWWidget):
         self._methodCB.currentTextChanged.connect(self._changeWidget)
 
     @Inputs.dataset
-    def setDataset(self, dataset):
+    def setDataset(self, _input):
         if self._widget:
             self.controlArea.layout().removeWidget(self._widget)
             self._widget.hide()
-        if dataset:
+        try:
+            dataset, update = _input
             self._dataset = dataset
-            if not dataset[0].dims.ndim:
+            if not dataset[1].dims.ndim:
                 msg = qt.QMessageBox()
                 msg.setIcon(qt.QMessageBox.Warning)
                 msg.setText("This widget has to be used before selecting any region of \
                              interest and after selecting the dimensions")
                 msg.exec_()
             else:
-                if dataset[0].dims.ndim == 1:
+                if dataset[1].dims.ndim == 1:
                     self._methodCB.show()
                     self._changeWidget("RSM")
                 else:
@@ -94,11 +97,19 @@ class TransformationWidgetOW(OWWidget):
                     self._widget.sigComputed.connect(self._sendSignal)
                     self.controlArea.layout().addWidget(self._widget)
                     self._widget.setDataset(*dataset)
-        else:
-            # Emit None
-            self.Outputs.dataset.send(dataset)
 
-        self.open()
+            if update is None:
+                self.open()
+            elif update != self._widget:
+                self.Outputs.dataset.send(((self,) + self._widget.getDataset(), update))
+        except Exception:
+            # Emit None
+            self.Outputs.dataset.send(None)
+
+    def _updateDataset(self, widget, dataset):
+        self._widget._updateDataset(widget, dataset)
+        if widget != self:
+            self.Outputs.dataset.send(((self,) + self._widget.getDataset(), widget))
 
     def _changeWidget(self, method):
         """
@@ -132,4 +143,4 @@ class TransformationWidgetOW(OWWidget):
             self.rotate = self._widget.rotate
             self.kind = True
         self.close()
-        self.Outputs.dataset.send(self._widget.getDataset())
+        self.Outputs.dataset.send(((self,) + self._widget.getDataset(), None))
